@@ -2,6 +2,7 @@
 
 #include "smallUsefulFunctions.h"
 #include "configmanagerinterface.h"
+#include "utilsSystem.h"
 
 #include "userquickdialog.h"
 
@@ -253,6 +254,7 @@ QString BuildManager::getCommandLine(const QString& id, bool* user){
 }
 
 QStringList BuildManager::parseExtendedCommandLine(QString str, const QFileInfo &mainFile, const QFileInfo &currentFile, int currentline) {
+	str = ConfigManagerInterface::getInstance()->parseDir(str);
 	str=str+" "; //end character  so str[i++] is always defined
 	QStringList result; result.append("");
 	for (int i=0; i<str.size(); i++) {
@@ -860,6 +862,7 @@ QString getCommandLineGhostscript(){ return ""; }
 #endif
 
 
+bool BuildManager_hadSuccessfulProcessStart;
 
 void BuildManager::registerOptions(ConfigManagerInterface& cmi){
 	cmi.registerOption("Tools/Quick Mode",&deprecatedQuickmode,-1);
@@ -877,7 +880,9 @@ void BuildManager::registerOptions(ConfigManagerInterface& cmi){
 	
 	cmi.registerOption("Tools/Display Names", &userToolDisplayNames, QStringList());
 	cmi.registerOption("Tools/User Order", &userToolOrder, QStringList());
-    cmi.registerOption("Tools/Preview Compile Time Out", &previewCompileTimeOut, 15000); //hidden option, 15s predefined
+	cmi.registerOption("Tools/Preview Compile Time Out", &previewCompileTimeOut, 15000); //hidden option, 15s predefined
+
+	cmi.registerOption("Tools/Had Successful Process Start", &BuildManager_hadSuccessfulProcessStart, false);
 }
 
 void removeDuplicateUserTools(QStringList &userToolOrder, QStringList &userToolDisplayNames) {
@@ -903,28 +908,26 @@ void BuildManager::readSettings(QSettings &settings){
 		if (rerunCommandsUnexpanded[i].startsWith(TXS_CMD_PREFIX))
 			rerunCommandsUnexpanded[i] = rerunCommandsUnexpanded[i].mid(TXS_CMD_PREFIX.size());
 
+	removeDuplicateUserTools(userToolOrder, userToolDisplayNames);
 	settings.beginGroup("Tools");
 	settings.beginGroup("Commands");
 	QStringList cmds = settings.childKeys();
 	foreach (const QString& id, cmds) {
 		QString cmd = settings.value(id).toString();
-		if (cmd.isEmpty()) continue;
 		CommandMapping::iterator it = commands.find(id);
-		if (it == commands.end()) registerCommand(id, "", id, "", "", 0, true).commandLine = cmd;
-		else {
+		if (it == commands.end()) {
+			// command not known by default -> user command
+			QString displayName(id);
+			int idx = userToolOrder.indexOf(id);
+			if (idx >= 0 && idx < userToolDisplayNames.length()) {
+				displayName = userToolDisplayNames[idx];
+			}
+			registerCommand(id, "", displayName, "", "", 0, true).commandLine = cmd;
+		} else {
+			// default command
 			it.value().commandLine = cmd;
 		}
 	}
-
-	removeDuplicateUserTools(userToolOrder, userToolDisplayNames);
-	for (int i=0; i<qMin(userToolOrder.size(), userToolDisplayNames.size()); ++i) {
-		QString id = userToolOrder[i];
-		CommandMapping::iterator it = commands.find(id);
-		if (it == commands.end()) {  // only use if there is not a standard command with the same name
-			registerCommand(id, "", userToolDisplayNames[i], "", "", 0, true);
-		}
-	}
-
 	settings.endGroup();
 	settings.endGroup();
 	
@@ -1167,30 +1170,8 @@ ProcessX* BuildManager::newProcessInternal(const QString &cmd, const QFileInfo&
 		proc->setWorkingDirectory(mainFile.absolutePath());
 	if (cmd.startsWith(TXS_CMD_PREFIX)) 
 		connect(proc, SIGNAL(startedX()), SLOT(runInternalCommandThroughProcessX()));
-	
-	QString addPaths = additionalSearchPaths;
-#ifdef Q_OS_MAC
-#if (QT_VERSION >= 0x040600)
-	QProcess *myProcess = new QProcess();
-	myProcess->start("bash -l -c \"echo $PATH\"");
-	myProcess->waitForFinished(3000);
-	if(myProcess->exitStatus()==QProcess::NormalExit){
-		QByteArray res=myProcess->readAllStandardOutput();
-		delete myProcess;
-		QString path(res);
-		if (addPaths.isEmpty()) addPaths = path;
-		else addPaths += ":" + path;
-	}
-#endif
-#endif
-	
 
-	if (!addPaths.isEmpty()) {
-		QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-		env.insert("PATH", env.value("PATH") + getPathListSeparator() + addPaths); //apply user path as well
-		proc->setProcessEnvironment(env);		
-	}	
-	
+	updatePathSettings(proc, additionalSearchPaths);
 	return proc;
 }
 
@@ -1826,14 +1807,20 @@ bool ProcessX::isRunning() const{
 void ProcessX::onStarted(){
 	if (isStarted) return; //why am I called twice?
 	isStarted=true;
+	BuildManager_hadSuccessfulProcessStart = true;
 	emit startedX();
 	emit processNotification(tr("Process started: %1").arg(cmd));
 }
 
 void ProcessX::onError(ProcessError error){
-	if (error == FailedToStart)
+	if (error == FailedToStart) {
 		emit processNotification(tr("Error: Could not start the command: %1").arg(cmd));
-	else if (error == Crashed)
+
+		if (!BuildManager_hadSuccessfulProcessStart)
+			emit processNotification("<br>" + tr("<b>Make sure that you have installed a (La)TeX distribution</b> e.g. MiKTeX or TeX Live, and have set the correct paths to this distribution on the command configuration page.<br>"
+										"A (La)TeX editor like TeXstudio cannot work without the (La)TeX commands provided by such a distribution."));
+
+	} else if (error == Crashed)
 		emit processNotification(tr("Error: Command crashed: %1").arg(cmd));
 }
 
