@@ -3,13 +3,17 @@
 #include "configmanager.h"
 
 LatexLogWidget::LatexLogWidget(QWidget *parent) :
-	QWidget(parent), logModel(0), displayPartsActions(0), logpresent(false)
+    QWidget(parent), logModel(0), displayPartsActions(0),filterErrorAction(0),filterWarningAction(0),filterBadBoxAction(0),logpresent(false)
 {
 	logModel = new LatexLogModel(this);//needs loaded line marks
 
 	errorTable = new QTableView(this);
 
-	errorTable->setModel(logModel);
+    proxyModel = new QSortFilterProxyModel(this);
+
+    //errorTable->setModel(logModel);
+    proxyModel->setSourceModel(logModel);
+    errorTable->setModel(proxyModel);
 
 	QFontMetrics fm(QApplication::font());
 	errorTable->setSelectionBehavior(QAbstractItemView::SelectRows);
@@ -24,6 +28,7 @@ LatexLogWidget::LatexLogWidget(QWidget *parent) :
 	errorTable->horizontalHeader()->setStretchLastSection(true);
 	errorTable->setMinimumHeight(5*(fm.lineSpacing()+4));
 	errorTable->setFrameShape(QFrame::NoFrame);
+    errorTable->setSortingEnabled(true);
 
 	QAction * act = new QAction(tr("&Copy"),errorTable);
 	connect(act, SIGNAL(triggered()), SLOT(copyMessage()));
@@ -70,6 +75,18 @@ LatexLogWidget::LatexLogWidget(QWidget *parent) :
 	displayLogAndTableAction = new QAction(tr("Issues and Log"), displayPartsActions);
 	displayLogAndTableAction->setData(qVariantFromValue(DisplayLogAndTable));
 	displayLogAndTableAction->setCheckable(true);
+    filterErrorAction = new QAction(QIcon(":/images-ng/error.svgz"),tr("Show Error"),this);
+    filterErrorAction->setCheckable(true);
+    filterErrorAction->setChecked(true);
+    connect(filterErrorAction,SIGNAL(toggled(bool)),this,SLOT(filterChanged(bool)));
+    filterWarningAction = new QAction(QIcon(":/images-ng/warning.svgz"),tr("Show Warning"),this);
+    filterWarningAction->setCheckable(true);
+    filterWarningAction->setChecked(true);
+    connect(filterWarningAction,SIGNAL(toggled(bool)),this,SLOT(filterChanged(bool)));
+    filterBadBoxAction = new QAction(QIcon(":/images-ng/badbox.svg"),tr("Show BadBox"),this);
+    filterBadBoxAction->setCheckable(true);
+    filterBadBoxAction->setChecked(true);
+    connect(filterBadBoxAction,SIGNAL(toggled(bool)),this,SLOT(filterChanged(bool)));
 
 	setDisplayParts(DisplayTable);
 }
@@ -152,9 +169,11 @@ bool LatexLogWidget::logEntryNumberValid(int logEntryNumber) {
 
 void LatexLogWidget::selectLogEntry(int logEntryNumber){
 	if (!logEntryNumberValid(logEntryNumber)) return;
-	errorTable->scrollTo(logModel->index(logEntryNumber,1),QAbstractItemView::PositionAtCenter);
-	errorTable->selectRow(logEntryNumber);
-	log->setCursorPosition(logModel->at(logEntryNumber).logline, 0);
+    QModelIndex index=proxyModel->mapFromSource(logModel->index(logEntryNumber,1));
+    errorTable->scrollTo(index,QAbstractItemView::PositionAtCenter);
+    //errorTable->selectRow(logEntryNumber);
+    errorTable->selectRow(index.row());
+    log->setCursorPosition(logModel->at(logEntryNumber).logline, 0);
 }
 
 void LatexLogWidget::copy() {
@@ -186,7 +205,8 @@ void LatexLogWidget::gotoLogEntry(int logEntryNumber) {
 }
 
 void LatexLogWidget::clickedOnLogModelIndex(const QModelIndex& index){
-	gotoLogEntry(index.row());
+    QModelIndex idx=proxyModel->mapToSource(index);
+    gotoLogEntry(idx.row());
 }
 
 void LatexLogWidget::gotoLogLine(int logLine){
@@ -194,7 +214,7 @@ void LatexLogWidget::gotoLogLine(int logLine){
 }
 
 void LatexLogWidget::copyMessage(){
-	QModelIndex curMessage = errorTable->currentIndex();
+    QModelIndex curMessage = proxyModel->mapToSource(errorTable->currentIndex());
 	if (!curMessage.isValid()) return;
 	curMessage = logModel->index(curMessage.row(), 3);
 	REQUIRE(QApplication::clipboard());
@@ -226,3 +246,23 @@ void LatexLogWidget::setInfo(const QString &message) {
 	infoLabel->setVisible(!message.isEmpty());
 }
 
+QList<QAction *> LatexLogWidget::displayActions(){
+    QList<QAction *> result=displayPartsActions->actions();
+	QAction *separator = new QAction(this);
+	separator->setSeparator(true);
+	result << filterErrorAction << filterWarningAction << filterBadBoxAction << separator;
+    return result;
+}
+
+void LatexLogWidget::filterChanged(bool ){
+    QStringList lst;
+    if(filterErrorAction && filterErrorAction->isChecked())
+        lst<<logModel->returnString(LT_ERROR);
+    if(filterWarningAction && filterWarningAction->isChecked())
+        lst<<logModel->returnString(LT_WARNING);
+    if(filterBadBoxAction && filterBadBoxAction->isChecked())
+        lst<<logModel->returnString(LT_BADBOX);
+    QString rg=lst.join("|");
+    proxyModel->setFilterRegExp(rg);
+    proxyModel->setFilterKeyColumn(1);
+}
