@@ -85,6 +85,7 @@ public:
 public slots:
     LatexEditorView* load(const QString &f , bool asProject = false, bool hidden = false, bool recheck=true);
 	void executeCommandLine(const QStringList& args, bool realCmdLine);
+	void startupCompleted();
 	void onOtherInstanceMessage(const QString &);  // For messages for the single instance
 	
 	void fuzzCursorHistory();
@@ -126,6 +127,8 @@ private:
 	void closeEvent(QCloseEvent *e);
 	
 	void updateUserMacros(bool updateMenu = true);
+
+    void updateEmphasizedRegion(QDocumentCursor c,int sid);
 	
 	QFormatScheme *m_formats, *m_formatsOldDefault;
 	QLanguageFactory* m_languages;
@@ -297,7 +300,8 @@ protected slots:
 	void editSectionPasteBefore(int line);
 	void editTextToLowercase();
 	void editTextToUppercase();
-	void editTextToTitlecase();
+	void editTextToTitlecase(bool smart=false);
+	void editTextToTitlecaseSmart();
 	void editFind();
 	void editPasteLatex();
 	void convertToLatex();
@@ -408,6 +412,7 @@ protected slots:
 	void QuickTabbing();
 	void QuickLetter();
 	void QuickDocument();
+	void QuickBeamer();
 	void QuickGraphics(const QString &graphicsFile = QString());
 	void QuickMath();
 	
@@ -562,6 +567,8 @@ protected slots:
 
     void openInternalDocViewer(QString package,const QString command="");
 
+    void colonTyped();
+
 private slots:
 	void importPackage(QString name);
 	void packageScanCompleted(QString name);
@@ -574,6 +581,9 @@ protected:
 	void dropEvent(QDropEvent *event);
 	virtual void changeEvent(QEvent *e);
 	virtual void resizeEvent(QResizeEvent *e);
+#if (QT_VERSION > 0x050000) && (defined(Q_OS_MAC))
+    bool eventFilter(QObject *obj, QEvent *event);
+#endif
 	
 	Qt::MouseButtons mb;
 	
